@@ -10,9 +10,13 @@ SPDX-License-Identifier: MIT
 
 //     Abstract:   C++ Metrics Discovery internal concurrent group implementation
 
+#include "md_adapter.h"
+#include "md_metrics_device.h"
 #include "md_concurrent_group.h"
+#include "md_metric_set.h"
 #include "md_information.h"
 #include "md_driver_ifc.h"
+#include "md_utils.h"
 
 #include <cstring>
 
@@ -702,6 +706,84 @@ namespace MetricsDiscoveryInternal
         return CC_OK;
     }
 
+    //////////////////////////////////////////////////////////////////////////////
+    //
+    // Class:
+    //     CConcurrentGroup
+    //
+    // Method:
+    //     InitializeMetricSet
+    //
+    // Description:
+    //     Initializes a metric set within the concurrent group
+    //
+    // Input:
+    //     CMetricSet*       set                  - metric set to initialize
+    //     TByteArrayLatest* platformMask         - platform Id bit mask indicates platforms compatible with set
+    //     const char*       availabilityEquation - availability equation
+    //     const uint32_t    gtMask               - gt type bit mask indicates platform versions compatible with set.
+    //
+    //////////////////////////////////////////////////////////////////////////////
+    CMetricSet* CConcurrentGroup::InitializeMetricSet( CMetricSet* set, TByteArrayLatest* platformMask, const char* availabilityEquation, const uint32_t gtMask )
+    {
+        const uint32_t adapterId = m_device.GetAdapter().GetAdapterId();
+
+        MD_CHECK_PTR_RET_A( adapterId, set, nullptr );
+
+        if( set->Initialize() != CC_OK )
+        {
+            MD_LOG_A( adapterId, LOG_ERROR, "Error initializing metrics" );
+            MD_SAFE_DELETE( set );
+            return nullptr;
+        }
+
+        if( set->SetAvailabilityEquation( availabilityEquation ) != CC_OK )
+        {
+            MD_LOG_A( adapterId, LOG_ERROR, "Error setting metric set equations" );
+            MD_SAFE_DELETE( set );
+            return nullptr;
+        }
+
+        CMetricSet* alreadyAddedSet = nullptr;
+        const char* symbolName      = set->GetParams()->SymbolName;
+
+        bool isSuitablePlatform = m_device.IsPlatformTypeOf( platformMask, gtMask ) && set->IsAvailabilityEquationTrue();
+        if( isSuitablePlatform )
+        {
+            // Check if metric set is already present in m_setsVector or m_otherSetsList.
+            alreadyAddedSet = GetMatchingMetricSet( symbolName, platformMask, gtMask, true );
+            if( alreadyAddedSet != nullptr )
+            {
+                // If metric set present in m_setsVector it should be move to m_otherSetsList.
+                // Metric set compared to alreadyAddedSet will be added in else section as unavailable on this platform.
+                auto iterator = std::find( m_setsVector.begin(), m_setsVector.end(), alreadyAddedSet );
+                if( iterator != m_setsVector.end() )
+                {
+                    MD_LOG_A( adapterId, LOG_WARNING, "Attempt to add metric set [%s] with the same name and true availability equation.", alreadyAddedSet->GetParams()->SymbolName );
+
+                    m_setsVector.erase( iterator );
+                    m_params.MetricSetsCount = static_cast<uint32_t>( m_setsVector.size() );
+
+                    m_otherSetsList.push_back( alreadyAddedSet );
+                }
+            }
+        }
+
+        if( isSuitablePlatform && alreadyAddedSet == nullptr )
+        {
+            m_setsVector.push_back( set );
+            m_params.MetricSetsCount = static_cast<uint32_t>( m_setsVector.size() );
+            MD_LOG_A( adapterId, LOG_INFO, "%s - added", symbolName );
+        }
+        else
+        {
+            MD_LOG_A( adapterId, LOG_INFO, "%s - not available", symbolName );
+            m_otherSetsList.push_back( set );
+        }
+
+        return set;
+    }
+
     //////////////////////////////////////////////////////////////////////////////
     //
     // Class:
